@@ -1,3 +1,5 @@
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
+
 /* Metacity interface for talking to GTK+ UI module */
 
 /* 
@@ -31,8 +33,6 @@
 
 /* This is between GTK_PRIORITY_RESIZE (+10) and GTK_PRIORITY_REDRAW (+20) */
 #define META_PRIORITY_RESIZE    (G_PRIORITY_HIGH_IDLE + 15)
-/* lower than GTK_PRIORITY_REDRAW */
-#define META_PRIORITY_COMPOSITE (G_PRIORITY_HIGH_IDLE + 25)
 
 typedef struct _MetaUI MetaUI;
 
@@ -42,7 +42,7 @@ typedef gboolean (* MetaEventFunc) (XEvent *xevent, gpointer data);
 
 void meta_ui_init (int *argc, char ***argv);
 
-Display* meta_ui_get_display       (const char *name);
+Display* meta_ui_get_display (void);
 
 void meta_ui_add_event_func    (Display       *xdisplay,
                                 MetaEventFunc  func,
@@ -116,7 +116,7 @@ MetaWindowMenu* meta_ui_window_menu_new   (MetaUI             *ui,
                                            Window              client_xwindow,
                                            MetaMenuOp          ops,
                                            MetaMenuOp          insensitive,
-                                           int                 active_workspace,
+                                           unsigned long       active_workspace,
                                            int                 n_workspaces,
                                            MetaWindowMenuFunc  func,
                                            gpointer            data);
@@ -181,14 +181,17 @@ gboolean meta_ui_have_a_theme      (void);
 
 gboolean meta_ui_parse_accelerator (const char          *accel,
                                     unsigned int        *keysym,
+                                    unsigned int        *keycode,
                                     MetaVirtualModifier *mask);
 gboolean meta_ui_parse_modifier    (const char          *accel,
                                     MetaVirtualModifier *mask);
 
+/* Caller responsible for freeing return string of meta_ui_accelerator_name! */
+gchar*   meta_ui_accelerator_name  (unsigned int        keysym,
+                                    MetaVirtualModifier mask);
 gboolean meta_ui_window_is_widget (MetaUI *ui,
                                    Window  xwindow);
 
-int      meta_ui_get_double_click_timeout (MetaUI *ui);
 int      meta_ui_get_drag_threshold       (MetaUI *ui);
 
 #include "tabpopup.h"
